# oak9 Tython Python SDK

## Requirements

Python 3.11+

## Unit Tests

To trigger unit tests, on the `py` folder run:

```shell
python -m unittest -v unit_tests/services/tython_api_services_test.py
```